@@ -3,15 +3,14 @@ from ruamel import yaml
 from setting.project_config import *
 
 
-def read_yaml(yaml_relative):
+def read_yaml(yaml_absolute_path):
     """
     读取yaml文件
-    :param yaml_relative: 参数为需要读取的yaml文件的相对路径
+    :param yaml_absolute_path: 参数为需要读取的yaml文件的绝对路径
     :return:
     """
 
-    with open(yaml_path + yaml_relative, "r",
-              encoding="utf-8") as f:
+    with open(yaml_absolute_path, "r", encoding="utf-8") as f:
         data_list = yaml.load(f, Loader=yaml.Loader)
     return data_list
     # 返回一个数据列表
@@ -43,13 +42,15 @@ def merge_yaml():
     for root, dirs, files in os.walk(yaml_path):
         # root为当前目录路径
         # dirs为当前路径下所有子目录，list格式
-        # files当前路径下所有非目录子文件，list格式
+        # files为当前路径下所有非目录子文件，list格式
         for i in files:
-            if i != first_test_case_file:
-                if os.path.splitext(i)[1] == '.yaml':
-                    # os.path.splitext()把路径拆分为文件名+扩展名
-                    yaml_list.append(i)
-    yaml_list.append(first_test_case_file)
+            if os.path.splitext(i)[1] == '.yaml':
+                # os.path.splitext()把路径拆分为文件名+扩展名
+                if i != first_test_case_file:
+                    yaml_list.append(os.path.join(root, i))
+                else:
+                    the_first_yaml = os.path.join(root, first_test_case_file)
+    yaml_list.append(the_first_yaml)
     # 加入第一个yaml文件
     yaml_list.reverse()
     # 反转排序
@@ -57,7 +58,7 @@ def merge_yaml():
     temporary_list = []
     for i in yaml_list:
         if i:
-            j = read_yaml('/' + i)
+            j = read_yaml(i)
             # 调用读取yaml文件的方法
             if j:
                 temporary_list.extend(j)
